# RenderedResourcePermissions

Response object for rendering ResourcePermissions. This includes any permissions granted to the user from groups, etc. 
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**resource_permissions** | [**list[ResourcePermission]**](ResourcePermission.md) | The permissions granted to the user | 
**user_id** | **str** | The id of the user to which the permissions apply | 
**org_id** | **str** | The id of the org to which the permissions apply | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


